#include "StdAfx.h"
#include "Utils.h"


CUtils::CUtils(void)
{
}


CUtils::~CUtils(void)
{
}

// Finds an attribute with the specified tag and a specified value.
// If found, the attribute text will be replaced with the new value.
void CUtils::ChangeAttributeValue(ACHAR *pAttributeTagName, ACHAR *pOldValue, ACHAR *pNewValue)
{
	AcApDocument *pActiveDoc = acDocManager->mdiActiveDocument();
	AcDbDatabase *pDB = pActiveDoc->database();

	// Get the block table 
	AcDbBlockTable *pBlockTable = NULL;
	Acad::ErrorStatus es = pDB->getBlockTable(pBlockTable, kForWrite);
	if(es != Acad::eOk)
	{
		acutPrintf(ACRX_T("\nError getting block table !"));
		return;
	}

	// Get the model space block table record
	bool bSave = false;
	AcDbBlockTableRecord *pModelSpace = NULL;
	pBlockTable->getAt(ACDB_MODEL_SPACE, pModelSpace, kForWrite); 
		
	// Iterate through the model space BTR to find block references
	AcDbBlockTableRecordIterator *pIter = NULL;
    pModelSpace->newIterator(pIter);
    for(;!pIter->done(); pIter->step())
    {
        AcDbObjectId entityId = AcDbObjectId::kNull;
        es = pIter->getEntityId(entityId);

		AcDbEntity *pBlockRefObj = NULL;
		es = acdbOpenObject(pBlockRefObj, entityId, kForRead); 

		if(pBlockRefObj->isKindOf(AcDbBlockReference::desc()) == false)
		{// Not a block reference !
			pBlockRefObj->close();
			continue;
		}
		AcDbBlockReference *pBlockRef = AcDbBlockReference::cast(pBlockRefObj);

		// Get the attributes for the block reference
		AcDbObjectIterator* attribIter = pBlockRef->attributeIterator();
		if (attribIter != NULL) 
		{
			while (attribIter->done() == false) 
			{
				AcDbAttribute *pAttribute = NULL;
				es = acdbOpenObject(pAttribute, attribIter->objectId(), kForRead); 
				if(es == Acad::eOk)
				{
					// Check if the attribute tag name is the one we are looking for
					if(_wcsicmp(pAttribute->tag(), pAttributeTagName) == 0)
					{
						// Check if the attribute value is the one we are looking for
						if(_tcscmp(pAttribute->textString(), pOldValue) == 0)
						{
							// Update the attribute with the new value.
							pAttribute->upgradeOpen(); 
							pAttribute->setTextString(pNewValue);
							acutPrintf(ACRX_T("\nReplacing %s with %s"), pOldValue, pNewValue);
							bSave = true;
						}
					}
					pAttribute->close();
				}
				attribIter->step();
			}
			delete attribIter;
		}
		pBlockRef->close();
    }
    delete pIter;
			
	pModelSpace->close();
	pBlockTable->close(); 

	if(bSave)
	{
		// Save the drawing if attribute has been modified.
		const ACHAR *pDrawingName = NULL;
		es = pDB->getFilename(pDrawingName);
		es = pDB->saveAs(pDrawingName, true, AcDb::kDHL_CURRENT);
		if(es == Acad::eOk)
		{
			acutPrintf(ACRX_T("\nDrawing saved as %s"), pDrawingName);
		}
		else
			acutPrintf(ACRX_T("\nError while saving the drawing"));
	}
}

