﻿// (C) Copyright 2002-2011 by Autodesk, Inc. 
//
// Permission to use, copy, modify, and distribute this software in
// object code form for any purpose and without fee is hereby granted, 
// provided that the above copyright notice appears in all copies and 
// that both that copyright notice and the limited warranty and
// restricted rights notice below appear in all supporting 
// documentation.
//
// AUTODESK PROVIDES THIS PROGRAM "AS IS" AND WITH ALL FAULTS. 
// AUTODESK SPECIFICALLY DISCLAIMS ANY IMPLIED WARRANTY OF
// MERCHANTABILITY OR FITNESS FOR A PARTICULAR USE.  AUTODESK, INC. 
// DOES NOT WARRANT THAT THE OPERATION OF THE PROGRAM WILL BE
// UNINTERRUPTED OR ERROR FREE.
//
// Use, duplication, or disclosure by the U.S. Government is subject to 
// restrictions set forth in FAR 52.227-19 (Commercial Computer
// Software - Restricted Rights) and DFAR 252.227-7013(c)(1)(ii)
// (Rights in Technical Data and Computer Software), as applicable.
//

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

namespace AccoreConsoleDemo
{
    public partial class SettingsForm : Form
    {
        public SettingsForm()
        {
            InitializeComponent();

            // Populate the settings form based on the values saved in the default settings.
            AcadInstallPath.Text = Properties.Settings.Default.AutoCAD2013InstallPath;
            drawingsFolderPathTextBox.Text = Properties.Settings.Default.DrawingsFolderPath;
            maxWaitDurationTextBox.Text = Properties.Settings.Default.MaxWaitTime.ToString();
            HideConsoleWindowCheckBox.Checked = Properties.Settings.Default.HideConsoleWindow; 
        }

        /// <summary>
        /// On click of the save button, persist the changes made to the settings.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void SaveBtn_Click(object sender, EventArgs e)
        {
            // Update the default settings based on the values specified by the user and save it.
            Properties.Settings.Default.AutoCAD2013InstallPath = AcadInstallPath.Text;
            Properties.Settings.Default.DrawingsFolderPath = drawingsFolderPathTextBox.Text;
            Properties.Settings.Default.MaxWaitTime = int.Parse(maxWaitDurationTextBox.Text);
            Properties.Settings.Default.HideConsoleWindow = HideConsoleWindowCheckBox.Checked; 
            Properties.Settings.Default.Save();
        }

        /// <summary>
        /// Displays the browse folder dialog to select the drawings folder path
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void BrowseFolderBtn_Click(object sender, EventArgs e)
        {
            if (DrawingsFolderBrowser.ShowDialog() == DialogResult.OK)
            {
                drawingsFolderPathTextBox.Text = DrawingsFolderBrowser.SelectedPath;
            }
        }

        /// <summary>
        /// Displays the browse folder dialog to select the Acad 2013 install path
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void AcadInstallPathBrowseBtn_Click(object sender, EventArgs e)
        {
            if (DrawingsFolderBrowser.ShowDialog() == DialogResult.OK)
            {
                AcadInstallPath.Text = DrawingsFolderBrowser.SelectedPath;
            }
        }
    }
}
