﻿// (C) Copyright 2011 by Autodesk, Inc. 
//
// Permission to use, copy, modify, and distribute this software in
// object code form for any purpose and without fee is hereby granted, 
// provided that the above copyright notice appears in all copies and 
// that both that copyright notice and the limited warranty and
//restricted rights notice below appear in all supporting 
//documentation.

//AUTODESK PROVIDES THIS PROGRAM "AS IS" AND WITH ALL FAULTS. 
//AUTODESK SPECIFICALLY DISCLAIMS ANY IMPLIED WARRANTY OF
//MERCHANTABILITY OR FITNESS FOR A PARTICULAR USE.  AUTODESK, INC. 
//DOES NOT WARRANT THAT THE OPERATION OF THE PROGRAM WILL BE
//UNINTERRUPTED OR ERROR FREE.

//Use, duplication, or disclosure by the U.S. Government is subject to 
//restrictions set forth in FAR 52.227-19 (Commercial Computer
//Software - Restricted Rights) and DFAR 252.227-7013(c)(1)(ii)
//(Rights in Technical Data and Computer Software), as applicable.

//Author: Philippe Leefsma, October 2011 - Autodesk Developer Technical Services

using System;
using Autodesk.AutoCAD.Runtime;
using Autodesk.AutoCAD.ApplicationServices;
using Autodesk.AutoCAD.DatabaseServices;
using Autodesk.AutoCAD.Geometry;
using Autodesk.AutoCAD.EditorInput;

[assembly: CommandClass(typeof(AcadCSharpInterpreter.AcadCommands))]

namespace AcadCSharpInterpreter
{
    public class AcadCommands
    {
        static Autodesk.AutoCAD.Windows.PaletteSet _ps = null;

        [CommandMethod("CSharpInterp")]
        public void CSharpInterp() 
        {
            if (_ps != null)
            {
                _ps.Visible = true;
                return;
            }

            _ps = new Autodesk.AutoCAD.Windows.PaletteSet("C# Interpreter");
            _ps.Text = "C# Interpreter";

            _ps.DockEnabled = Autodesk.AutoCAD.Windows.DockSides.Left |
                Autodesk.AutoCAD.Windows.DockSides.Right |
                Autodesk.AutoCAD.Windows.DockSides.None;

            _ps.Style = Autodesk.AutoCAD.Windows.PaletteSetStyles.ShowPropertiesMenu |
                       Autodesk.AutoCAD.Windows.PaletteSetStyles.ShowAutoHideButton |
                       Autodesk.AutoCAD.Windows.PaletteSetStyles.ShowCloseButton;

            _ps.MinimumSize = new System.Drawing.Size(200, 300);
            _ps.Size = new System.Drawing.Size(300, 500);

            System.Windows.Forms.Control ctrl =
                new AcadControl();

            Autodesk.AutoCAD.Windows.Palette palette = _ps.Add("C# Interpreter", ctrl);

            _ps.Visible = true;
        }

        [CommandMethod("RegisterCSharpInterp")]
        public static void RegisterCSharpInterp()
        {
            //AutoCAD (or vertical) and Application keys
            Microsoft.Win32.RegistryKey acadKey =
                Microsoft.Win32.Registry.CurrentUser.OpenSubKey(HostApplicationServices.Current.MachineRegistryProductRootKey);

            Microsoft.Win32.RegistryKey acadAppKey = acadKey.OpenSubKey("Applications", true);

            string curAssemblyName = System.Reflection.Assembly.GetExecutingAssembly().GetName().Name;

            //already registered?
            String[] subKeys = acadAppKey.GetSubKeyNames();
            foreach (String subKey in subKeys)
            {
                if (subKey.Equals(curAssemblyName))
                {
                    acadAppKey.Close();
                    return;
                }
            }

            //assembly location and description (as full name)
            string curAssemblyPath = System.Reflection.Assembly.GetExecutingAssembly().Location;
            string curAssemblyFullName = System.Reflection.Assembly.GetExecutingAssembly().GetName().FullName;

            //create the addin key
            Microsoft.Win32.RegistryKey acadAppAddInKey = acadAppKey.CreateSubKey(curAssemblyName);

            acadAppAddInKey.SetValue("DESCRIPTION", curAssemblyFullName, Microsoft.Win32.RegistryValueKind.String);
            acadAppAddInKey.SetValue("LOADCTRLS", 14, Microsoft.Win32.RegistryValueKind.DWord);
            acadAppAddInKey.SetValue("LOADER", curAssemblyPath, Microsoft.Win32.RegistryValueKind.String);
            acadAppAddInKey.SetValue("MANAGED", 1, Microsoft.Win32.RegistryValueKind.DWord);

            acadAppKey.Close();
        }

        [CommandMethod("UnregisterCSharpInterp")]
        public void UnregisterCSharpInterp()
        {
            //AutoCAD (or vertical) and Application keys
            Microsoft.Win32.RegistryKey acadKey =
                Microsoft.Win32.Registry.CurrentUser.OpenSubKey(HostApplicationServices.Current.MachineRegistryProductRootKey);

            Microsoft.Win32.RegistryKey acadAppKey = acadKey.OpenSubKey("Applications", true);

            //get assembly name and delete
            string curAssemblyName = System.Reflection.Assembly.GetExecutingAssembly().GetName().Name;

            String[] subKeys = acadAppKey.GetSubKeyNames();

            foreach (String subKey in subKeys)
            {
                if (subKey.Equals(curAssemblyName))
                {
                    acadAppKey.DeleteSubKeyTree(curAssemblyName);
                }
            }

            acadAppKey.Close();
        }

        [CommandMethod("LoadedAssemblies")]
        public void LoadedAssemblies()
        {
            Document doc = Application.DocumentManager.MdiActiveDocument;
            Editor ed = doc.Editor;

            System.Reflection.Assembly[] assemblies = System.AppDomain.CurrentDomain.GetAssemblies();

            foreach (System.Reflection.Assembly assembly in assemblies)
            {
                //let's remove built-in .NET assemblies
                if (!assembly.Location.ToLower().Contains("windows"))
                {
                    ed.WriteMessage("\n - " + assembly.Location);
                }
            }
        }
    }
}
